var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
import React, { forwardRef, Fragment, useCallback, } from "react";
import cn from "classnames";
import { CSSTransition } from "react-transition-group";
import { Overlay } from "@react-md/overlay";
import { ConditionalPortal, } from "@react-md/portal";
import { bem } from "@react-md/theme";
import { FocusContainer, useScrollLock } from "@react-md/wia-aria";
import useNestedDialogFixes from "./useNestedDialogFixes";
// used to disable the overlay click-to-close functionality when the `modal` prop is enabled.
var noop = function () { };
var block = bem("rmd-dialog");
var overlayBlock = bem("rmd-dialog-overlay");
var Dialog = function (providedProps) {
    var _a = providedProps, children = _a.children, forwardedRef = _a.forwardedRef, className = _a.className, forceContainer = _a.forceContainer, containerStyle = _a.containerStyle, containerClassName = _a.containerClassName, propOverlay = _a.overlay, overlayStyle = _a.overlayStyle, overlayClassName = _a.overlayClassName, visible = _a.visible, onRequestClose = _a.onRequestClose, portal = _a.portal, portalInto = _a.portalInto, portalIntoId = _a.portalIntoId, classNames = _a.classNames, timeout = _a.timeout, mountOnEnter = _a.mountOnEnter, unmountOnExit = _a.unmountOnExit, onEnter = _a.onEnter, onEntering = _a.onEntering, onEntered = _a.onEntered, onExit = _a.onExit, onExiting = _a.onExiting, onExited = _a.onExited, modal = _a.modal, type = _a.type, defaultFocus = _a.defaultFocus, propDisableEscapeClose = _a.disableEscapeClose, disableNestedDialogFixes = _a.disableNestedDialogFixes, onKeyDown = _a.onKeyDown, props = __rest(_a, ["children", "forwardedRef", "className", "forceContainer", "containerStyle", "containerClassName", "overlay", "overlayStyle", "overlayClassName", "visible", "onRequestClose", "portal", "portalInto", "portalIntoId", "classNames", "timeout", "mountOnEnter", "unmountOnExit", "onEnter", "onEntering", "onEntered", "onExit", "onExiting", "onExited", "modal", "type", "defaultFocus", "disableEscapeClose", "disableNestedDialogFixes", "onKeyDown"]);
    var id = props.id;
    var isFullPage = type === "full-page";
    var isCentered = type === "centered";
    var _b = useNestedDialogFixes({
        id: id,
        visible: visible,
        disabled: disableNestedDialogFixes,
        disableEscapeClose: propDisableEscapeClose,
    }), disableOverlay = _b.disableOverlay, disableEscapeClose = _b.disableEscapeClose;
    useScrollLock(visible);
    var handleKeyDown = useCallback(function (event) {
        if (onKeyDown) {
            onKeyDown(event);
        }
        if (!disableEscapeClose && !modal && event.key === "Escape") {
            onRequestClose();
        }
    }, [onKeyDown, disableEscapeClose, modal]);
    var overlayEl = null;
    if (typeof propOverlay === "boolean" ? propOverlay : !isFullPage) {
        overlayEl = (React.createElement(Overlay, { id: id + "-overlay", style: overlayStyle, className: cn(overlayBlock({ "no-pointer": modal, hidden: disableOverlay }), overlayClassName), visible: visible, onRequestClose: modal ? noop : onRequestClose }));
    }
    var dialog = (React.createElement(FocusContainer, __assign({}, props, { "aria-modal": true, onKeyDown: handleKeyDown, className: cn(block({
            centered: isCentered,
            "full-page": isFullPage,
        }), className) }), children));
    if (isCentered || forceContainer) {
        // the additional container is only required when we don't have a full page dialog. it's just
        // used to apply flex center to the dialog and add some margin
        dialog = (React.createElement("span", { id: id + "-container", style: containerStyle, className: cn("rmd-dialog-container", containerClassName) }, dialog));
    }
    return (React.createElement(ConditionalPortal, { portal: portal, portalInto: portalInto, portalIntoId: portalIntoId },
        React.createElement(Fragment, null,
            overlayEl,
            React.createElement(CSSTransition, { appear: mountOnEnter, in: visible, classNames: classNames, timeout: timeout, onEnter: onEnter, onEntering: onEntering, onEntered: onEntered, onExit: onExit, onExiting: onExited, onExited: onExited, mountOnEnter: mountOnEnter, unmountOnExit: unmountOnExit }, dialog))));
};
var defaultProps = {
    role: "dialog",
    type: "centered",
    tabIndex: -1,
    portal: true,
    modal: false,
    mountOnEnter: true,
    unmountOnExit: true,
    timeout: {
        enter: 200,
        exit: 150,
    },
    classNames: {
        appear: "rmd-dialog--enter",
        appearActive: "rmd-dialog--enter-active",
        enter: "rmd-dialog--enter",
        enterActive: "rmd-dialog--enter-active",
        exit: "rmd-dialog--exit",
        exitActive: "rmd-dialog--exit-active",
    },
    defaultFocus: "first",
    forceContainer: false,
    disableEscapeClose: false,
    disableNestedDialogFixes: false,
};
Dialog.defaultProps = defaultProps;
if (process.env.NODE_ENV !== "production") {
    Dialog.displayName = "Dialog";
    var PropTypes = null;
    try {
        PropTypes = require("prop-types");
    }
    catch (e) { }
    if (PropTypes) {
        Dialog.propTypes = {
            id: PropTypes.string.isRequired,
            role: PropTypes.oneOf(["dialog", "alertdialog"]),
            className: PropTypes.string,
            type: PropTypes.oneOf(["none", "centered", "full-page"]),
            tabIndex: PropTypes.number,
            modal: PropTypes.bool,
            visible: PropTypes.bool.isRequired,
            onRequestClose: PropTypes.func.isRequired,
            overlay: PropTypes.bool,
            overlayStyle: PropTypes.object,
            overlayClassName: PropTypes.string,
            containerStyle: PropTypes.object,
            containerClassName: PropTypes.string,
            forceContainer: PropTypes.bool,
            children: PropTypes.node,
            classNames: PropTypes.oneOfType([
                PropTypes.string,
                PropTypes.shape({
                    appear: PropTypes.string,
                    appearActive: PropTypes.string,
                    enter: PropTypes.string,
                    enterActive: PropTypes.string,
                    enterDone: PropTypes.string,
                    exit: PropTypes.string,
                    exitActive: PropTypes.string,
                    exitDone: PropTypes.string,
                }),
            ]),
            timeout: PropTypes.oneOfType([
                PropTypes.number,
                PropTypes.shape({
                    enter: PropTypes.number,
                    exit: PropTypes.number,
                }),
            ]),
            onEnter: PropTypes.func,
            onEntering: PropTypes.func,
            onEntered: PropTypes.func,
            onExit: PropTypes.func,
            onExiting: PropTypes.func,
            onExited: PropTypes.func,
            portal: PropTypes.bool,
            portalInto: PropTypes.oneOfType([
                PropTypes.func,
                PropTypes.string,
                PropTypes.object,
            ]),
            "aria-label": PropTypes.string,
            "aria-labelledby": PropTypes.string,
            disableEscapeClose: PropTypes.bool,
            disableNestedDialogFixes: PropTypes.bool,
            defaultFocus: PropTypes.oneOfType([
                PropTypes.oneOf(["first", "last"]),
                PropTypes.string,
            ]),
        };
    }
}
export default forwardRef(function (props, ref) { return (React.createElement(Dialog, __assign({}, props, { forwardedRef: ref }))); });
//# sourceMappingURL=Dialog.js.map